#
# spec file for package percona-toolkit
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define revision 6917c5d

Name:           percona-toolkit
Version:        3.3.1
Release:        2.15
Summary:        Advanced MySQL and system command-line tools
License:        GPL-2.0-only
Group:          Productivity/Databases/Tools
URL:            https://www.percona.com/software/percona-toolkit/
Source:         https://www.percona.com/downloads/%{name}/%{version}/source/tarball/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        %{name}.conf
Source9:        series
Patch1:         go-build.patch
Requires:       perl(DBD::mysql) >= 1.0
Requires:       perl(DBI) >= 1.13
Requires:       perl(IO::Socket::SSL)
Requires:       perl(Term::ReadKey) >= 2.10
Requires:       perl(Time::HiRes)
Provides:       maatkit = 7410.%{version}
Obsoletes:      maatkit < 7410
BuildRequires:  golang-packaging
BuildRequires:  golang(API)
%{perl_requires}
%{go_nostrip}

%description
Percona Toolkit is a collection of advanced command-line tools used by
Percona (http://www.percona.com/) support staff to perform a variety of
MySQL and system tasks that are too difficult or complex to perform manually.

These tools are ideal alternatives to private or "one-off" scripts because
they are professionally developed, formally tested, and fully documented.
They are also fully self-contained, so installation is quick and easy and
no libraries are installed.

Percona Toolkit is developed and supported by Percona Inc.  For more
information and other free, open-source software developed by Percona,
visit http://www.percona.com/software/.

This collection was formerly known as Maatkit.

%prep
%autosetup -p1 -a 1

%build
perl Makefile.PL INSTALLDIRS=vendor < /dev/null
sed -i 's|%{_bindir}/env perl|%{_bindir}/perl|' bin/*
sed -i 's|%{_bindir}/env bash|%{_bindir}/bash|' bin/*
%make_build
pushd src/go
make linux \
  TOP_DIR=../../ \
  BIN_DIR=../../bingo/ \
  VERSION=%{version} \
  BUILD=$(date -u '+%FT%T%z' -d @${SOURCE_DATE_EPOCH}) \
  COMMIT=%{revision} 
popd

%install
%perl_make_install
%perl_process_packlist
rm -rf %{buildroot}%{_prefix}/lib
rm -rf %{buildroot}/lib
rm -rf %{buildroot}/%{perl_vendorarch}/auto/%{name}
rm -rf %{buildroot}%{_localstatedir}/adm/perl-modules/%{name}
# a blank configuration file
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
cp %{SOURCE2} %{buildroot}%{_sysconfdir}/%{name}/
cp -a bingo/* %{buildroot}%{_bindir}/

%files
%license COPYING
%doc README.md Changelog
%dir %{_sysconfdir}/%{name}
%{_bindir}/*
%{_mandir}/man1/*.1p.gz
%config %{_sysconfdir}/%{name}/%{name}.conf

%changelog
* Tue Oct  5 2021 Marcus Rueckert <mrueckert@suse.de>
- enable golang based tools
  1. package is no longer noarch
  2. added go-build.patch
  3. add BR for golang tools
* Fri Apr 30 2021 Denys Kondratenko <stdden@opensuse.org>
- Percona Toolkit v3.3.1:
  * BEFORE triggers are dropped after pt-online-schema-change run
  * pt-summary reports wrong memory size
  * drop_swap can drop triggers
  * Column data lost when ‘Generated’ is in the column comment
* Mon Apr 26 2021 Martin Pluskal <mpluskal@suse.com>
- Cleanup spec file
- Fetch correct sources
* Sat Apr 24 2021 Denys Kondratenko <stdden@opensuse.org>
- Percona Toolkit v3.3.0:
  * Fix pt-heartbeat cannot reconnect
  * Fix pt-online-schema-change FKs error handling
  * Fix pt-summary says sshd not running
  * Fix pt-upgrade fails when query including format strings and SQL errors is given
  * Fix pt-pg-summary fails for Postgres12
  * Added --no-check-foreing-keys to pt-osc
  * Backslashes missing from documentation
  * Review and consider lintian reported issues
  * Fix pt-heartbeat doesn't reconnect for check-read-only
  * Fix pt-mongodb-summary fails on standalone mongodb instances
  * Fix pt-table-checksum gives error CRC32
* Tue Oct 27 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Percona Toolkit 3.2.1:
  * Fix pt-pg-summary failing for Postgres12
  * Add --no-check-foreing-keys to pt-osc
  * Fix pt-heartbeat not reconnecting for check-read-only
  * Fix pt-mongodb-summary failing  on standalone mongodb instances
  * Fix pt-table-checksum error CRC32
* Mon Sep  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Wed May 27 2020 Andreas Stieger <andreas.stieger@gmx.de>
- Percona Toolkit 3.2.0:
  * Add IPv6 support
  * Fix handling of year 2020
  * Fix FK warnings and bugs in pt-online-schema-change
  * Fix regression on slave with replication channels
  * Fix pt-stalk not collecting processlist and variables
  * Fix pt-online-schema-change not working with multi-source replication
  * Fix a bug in pt-online-schema-change can break replication
* Sun Sep 22 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to Percona Toolkit 3.1.0:
  * the new pt-pg-summary tool supports PostgreSQL data collection
  in a way similar to other PT summary tools
  * Add options to pt-stalk that allow limiting the disk space use
  * pt-online-schema-change will not run under MySQL 8.0.14...17
  if the table has foreign keys to avoid triggering a bug
- includes changes from 3.0.13:
  * MariaDB 10+ compatibility fixes
  * various bug fixes in multiple tools
* Fri Nov 23 2018 astieger@suse.com
- update to Percona Toolkit 3.0.12:
  * pt-archiver failed with UTF-8 chars
  * pt-online-schema-change failed on UK and NULLs
  * Better usage of ENUM fields in keys in NibbleIterator
  * pt-mysql-summary may get stuck when Time: NULL in processlist
* Tue Aug 14 2018 jon@moozaad.co.uk
- update to Percona Toolkit 3.0.11:
  * 3.x adds tools for MongoDB
  * Removed check version patches fixed 2.2.7,
    drop percona-toolkit-2.2.x-disable-default-version-check.patch
* Sun Dec 11 2016 astieger@suse.com
- Percona Toolkit 2.2.20
- new features:
  * pt-query-digest numbers in table or column names converted to
    question marks (--preserve-embedded-numbers)
  * Added pause to NibbleIterator
  * --data-dir parameter in order to create the table on a different
    partition
  * with pt-table-checksum automatically exclude checking schemas
    named percona, percona_schema
  * pt-online-schema-change Added --remove-data-dir feature
  * Add Transparent huge pages info to pt-summary
  * Add Memory management library to pt-mysql-summary
- bug fixes:
  * Fixed several typos in the doc
  * pt-slave-restart fails on MariaDB 10.0.13
  * pt-show-grants fails against MariaDB10+
  * pt-online-schema-change misses data.  Fixed sort order for
    ENUM fields
  * pt-online-schema-change doesn't apply underscores to foreign
    keys individually
  * pt-upgrade fails with SELECT INTO
  * pt-slave-restart --config does not recognize = as separator
- includes changes from 2.2.19:
  * Recheck the list of slaves while OSC run
  * pt-osc should error if server is a slave in row based
    replication
  * pt-table-checksum should force replica table charset to utf8
  * Added --create-table-engine param to pt-heartbeat
  * SlowLogParser is able to handle dates in RFC339 format for
    MySQL 5.7
  * pt-kill leaks memory each time it kills a query
  * Large BLOB/TEXT/BINARY Produces NULL Checksum
  * Fixed pt-archiver deletes wrong rows #103
  * Added --slave-user and --slave-password to
    pt-online-schema-change & pt-table-sync
  * Handle GTID ranges where the left-side integer is larger than 9
  * Remove extra word 'default' from the --verbose help
  * add enum column type to is_char check so that values are
    properly quoted
* Mon Jul 11 2016 astieger@suse.com
- Percona Toolkit 2.2.18
  * pt-stalk now sorts the output of transactions by id
  * Added "Shared" memory info to pt-summary
  * Added the --no-vertical-format option for pt-query-digest,
    allowing compatibility with non-standard MySQL clients that
    don't support the \G directive at the end of a statement
  * Fixed error when parsing tcpdump capture with pt-query-digest
  * Improved pt-online-schema-change plugin documentation
  * Clarified the description of the --attribute-value-limit
    option for pt-query-digest
  * Fixed all PERL-based tools to return a zero exit status when
    run with the --version option
  * Fixed error that sometimes prevented to choose the primary key
    as index, when using the -where option for pt-table-checksum
  * Fixed the inability of pt-query-digest to parse the general
    log generated by MySQL (and Percona Server) 5.7 instance
  * Clarified the description of the --verbose option for\
    pt-slave-restart
* Sun Mar 13 2016 astieger@suse.com
- Percona Toolkit 2.2.17
- New features:
  * General compatibility with MySQL 5.7 tools, docs and test suite
- Fixed bugs:
  * pt-mysql-summary displays incorrect info about Fast Server
  Restarts for Percona Server 5.6
  * pt-online-schema-change cannot set sql_mode using --set-vars
  * pt-online-schema-change added --null-to-non-null option to
  allow NULLable columns to be converted to NOT NULL
  * pt-online-schema-change doesn't apply underscores to foreign
  keys individually
  * pt-online-schema Invalid recursion method: t=dsns
  * pt-online-schema-change fails when using --no-drop-old-table
  after 10 times
  * pt-query-digest : Redundant argument in sprintf
  * pt-query-digest doc bug with --since and too many colons
  * pt-query-digest: Make documentation of --attribute-value-limit
  option more clear
  * pt-show-grants fails against MySQL-5.7.6
  * pt-show-grants doesn't sort column-level privileges
  * pt-slave-restart fails on MariaDB 10.0.13 (gtid_mode confusion)
  * pt-stalk: new var binlog_error_action causes bug in collect
  module
  * pt-table-checksum has high likelyhood to skip a table when row
  count is around chunk-size * chunk-size-limit
  * pt-table-checksum redundant argument in printf
* Sun Nov 15 2015 astieger@suse.com
- Percona Toolkit 2.2.16:
  * pt-online-schema-change: Run with --analyze-before-swap by
    default to prevent performance issues,  disable with
  - -no-analyze-before-swap
  * pt-online-schema-change:  Wait forever for available slave
  * pt-archiver: ssues ‘keepalive’ queries during and after bulk
    insert/delete process that takes a long time.
  * The --filter option for pt-kill now works correctly.
* Fri Aug 28 2015 astieger@suse.com
- Percona Toolkit 2.2.15
- New features:
  * Flow control in clusters:
    pt-online-schema-change: add --max-flow-ctl option
    pt-archiver: add --max-flow-ctl option
  * pt-online-schema-change: add --sleep option
  * pt-archiver: add ability to specify --check-slave-lag multiple
    times for multiple slaves
  * pt-kill: add --rds option to use Amazon RDS procedure calls
    instead of the standard MySQL kill command.
- Various bug fixes
* Tue Apr 14 2015 astieger@suse.com
- Percona Toolkit 2.2.14
  * pt-slave-find can now resolve the IP address and show the
    slave's hostname. This can be done with the new
  - -resolve-address option.
  * pt-table-sync can now ignore the tables whose names match a
    specific Perl regex with the new --ignore-tables-regex option.
  * Fixed lp#925781: Inserting non-BMP characters into a column
    with utf8 charset would cause the Incorrect
    string value error when running the
    pt-table-checksum.
  * Fixed lp#1368244: pt-online-schema-change
  - -alter-foreign-keys-method=drop-swap` was
    not atomic and thus it could be interrupted.
    Fixed by disabling common interrupt signals
    during the critical drop-rename phase.
  * Fixed lp#1381280: pt-table-checksum was failing on BINARY field
    in Primary Key. Fixed by implementing new
  - -binary-index flag to optionally create
    checksum table using BLOB data type.
  * Fixed lp#1421405: Running pt-upgrade against a log with many
    identical (or similar) queries was producing
    repeated sections with the same fingerprint.
  * Fixed lp#1402730: pt-duplicate-key-checker was not checking for
    duplicate keys when --verbose option was set.
  * Fixed lp#1406390: A race condition was causing pt-heartbeat to
    crash with sleep argument error.
  * Fixed lp#1417558: pt-stalk when used along with
  - -collect-strace didn't write the strace
    output to the expected destination file.
  * Fixed lp#1421781: pt-upgrade would fail when log contained
    SELECT...INTO queries. Fixed by ignoring/
    skipping those queries.
  * Fixed lp#1425478: pt-stalk was removing non-empty files that
    were starting with an empty line.
  * Fixed lp#1419098: Fixed bad formatting in the pt-table-checksum
    documentation.
* Tue Feb 24 2015 astieger@suse.com
- add CVE/bug tracking to 2.2.13 changelog entry
* Mon Jan 26 2015 andreas.stieger@gmx.de
- Percona Toolkit 2.2.13:
  * Feature lp#1391240: pt-kill added query fingerprint hash to
    output
  * Fixed lp#1402668: pt-mysql-summary fails on cluster in
    Donor/Desynced status
  * Fixed lp#1396870: pt-online-schema-change CTRL+C leaves
    terminal in inconsistent state
  * Fixed lp#1396868: pt-online-schema-change --ask-pass option
    error
  * Fixed lp#1266869: pt-stalk fails to start if $HOME environment
    variable is not set
  * Fixed lp#1019479: pt-table-checksum does not work with sql_mode
    ONLY_FULL_GROUP_BY
  * Fixed lp#1394934: pt-table-checksum error in debug mode
  * Fixed lp#1321297: pt-table-checksum reports diffs on timestamp
    columns in 5.5 vs 5.6
  * Fixed lp#1399789: pt-table-checksum fails to find pxc nodes
    when wsrep_node_incoming_address is set to
    AUTO
  * Fixed lp#1388870: pt-table-checksum has some errors with
    different time zones
  * Fixed lp#1408375: vulnerable to MITM attack which would allow
    exfiltration of MySQL configuration
    information via --version-check
    [boo#919298] [CVE-2015-1027]
  * Fixed lp#1404298: missing MySQL5.7 test files for
    pt-table-checksum
  * Fixed lp#1403900: added sandbox and fixed sakila test db for
    5.7
* Mon Nov 17 2014 andreas.stieger@gmx.de
- Percona Toolkit 2.2.12:
  * Fixed lp#1376561: pt-archiver is not able to archive all the
    rows when a table has a hash partition
  * Fixed lp#1328686: pt-heartbeat check-read-only option does not
    prevent creates or inserts
  * Fixed lp#1269695: pt-online-schema-change does not allow ALTER
    for a table without a non-unique, while
    manual does not explain this
  * Fixed lp#1217466: pt-table-checksum refuses to run on PXC if
    server_id is the same on all nodes
  * Fixed lp#1373937: pt-table-checksum requires recursion when
    working with and XtraDB Cluster node
  * Fixed lp#1377888: pt-query-digest manual for --type binlog is
    ambiguous
  * Fixed lp#1349086: pt-stalk should also gather dmesg output
  * Fixed lp#1361293: Some scripts fail when no-version-check
    option is put in global config file
* Fri Sep 26 2014 andreas.stieger@gmx.de
- Percona Toolkit 2.2.11:
  * Fixed bug: pt-query-digest doesn't report host details
  * Fixed bug: pt-mysql-summary incorrectly tries to parse
    key/value pairs in wsrep_provider_options resulting
    in incomplete my.cnf information
  * Fixed bug: pt-stalk should use SQL_NO_CACHE
  * Fixed bug: pt-stalk handles mysql user password in awkward way
  * Fixed bug: Various issues with tests
  * Fixed bug: pt-summary problem parsing dmidecode output on some
    machines
  * Fixed bug: Typo in pt-variable-advisor
* Sun Aug 10 2014 andreas.stieger@gmx.de
- Percona Toolkit 2.2.10
  * Fixed bug: pt-table-checksum deadlock
  * Fixed bug: 5.6 slow query log Thead_id becomes Id
  * Fixed bug: pt-table-checksum + PXC inconsistent results upon
  - -resume
  * Fixed bug: pt-online-schema-change doesn't work with HASH
    indexes
  * Fixed bug: pt-table-checksum max load 20%% rounds down
  * Fixed bug: some shell tools output error when queried for
  - -version
* Thu Jul 10 2014 andreas.stieger@gmx.de
- Percona Toolkit 2.2.9
  * pt-query-digest could not parse the binlogs from MySQL 5.6
    because the binlog format was changed.
  * pt-online-schema-change did not find child tables as expected.
  * pt-stalk would fail when variable or threshold was a non-integer.
  * pt-deadlock-logger was inserting older deadlocks into the deadlock
    table even if it was already there
  * pt-online-schema-change foreign-keys-method=none cloud break FK
    constraints in a way that is hard to recover from
* Thu Jun  5 2014 andreas.stieger@gmx.de
- Percona Toolkit 2.2.8
  * Removed pt-agent
  * Added pt-slave-restart GTID support
  * Added pt-table-checksum --plugin
  * Fixed bug: --ignore-tables does not work correctly
  * Fixed bug: pt-deadlock-logger logs incorrect ts
  * Fixed bug: pt-mysql-summary blank InnoDB section for 5.6
  * Fixed bug: pt-online-schema-change requests password twice
  * Fixed bug: pt-query-digest dosn't fingerprint true/false
    literals correctly
  * Fixed bug: pt-show-grant --ask-pass prints "Enter password" to
    STDOUT
- some spec cleanup
- refresh percona-toolkit-2.2.x-disable-default-version-check.patch
  to not fail %%check
* Mon Feb 24 2014 andreas.stieger@gmx.de
- Percona Toolkit 2.2.7  [bnc#864194] CVE-2014-2029
  Improves sanitisation of input and output for commands run when
  performing a version check.
  As this would still transmit data to an external entity without
  prompting, the automatic version check remains disabled in this
  package unless requested via command line or global/tool specific
  or user configuratoin. (--version-check)
* Sun Feb 16 2014 andreas.stieger@gmx.de
- disable automatic version check for all tools
  [bnc#864194] CVE-2014-2029
  Prevents transmission of version information to an external host
  in the default configuration.
  Can be used by owner of a Percona Server (or an attacker who can
  control this destination for the client) to collect arbitrary
  MySQL configuration parameters and execute commands (with -v).
  Now the version check needs to be requested via command line or
  global/tool specific/user configuration. (--version-check)
- added /etc/percona-toolkit/percona-toolkit.conf configuration
  directory and template configuration file
- added patches:
  * percona-toolkit-2.2.x-disable-default-version-check.patch
* Fri Dec 27 2013 andreas.stieger@gmx.de
- update to 2.2.6 [bnc#856861]
  Strongly recommended bugfix release fixing potential data loss
- highlighted fixes:
  * pt-table-sync deletes child table rows
    In the worst case, pt-table-sync could delete all rows in child
    tables. Now pt-table-sync has option --[no]check-child-tables
    which is on by default. In cases were this can be triggered,
    pt-table-sync prints a warning and skips the table.
  * pt-duplicate-key-checker misses exact duplicate unique indexes
  * pt-online-schema-change gets stuck looking for its own _new table
  * pt-mysql-summary schema dump prompt can't be disabled
    pt-mysql-summary no longer prompts to dump and summarize schemas.
    To do this, you must specify --databases or, a new option,
  - -all-databases. Potentially backwards-incompatible change.
- added options:
  * Added pt-query-digest support for Percona Server slow log rate limiting
  * Added pt-agent --ping
  * Added pt-mysql-summary --all-databases
  * Added pt-stalk --sleep-collect
  * Added pt-table-sync --[no]check-child-tables
- further changes:
  * PTDEBUG prints some info to STDOUT
  * pt-agent requires restart after changing MySQL options
  * pt-agent --install on PXC is not documented
  * pt-agent --install doesn’t check for previous install
  * pt-agent --install suggest MySQL user isn’t quoted
  * pt-agent --install error about slave is confusing
  * pt-agent --uninstall fails if agent is running
  * pt-agent docs don’t list privs required for its MySQL user
  * pt-deadlock-logger docs use pt-fk-error-logger
  * pt-duplicate-key-checker error when EXPLAIN key_len=0
  * pt-query-digest stats prints to STDOUT instead of STDERR
  * pt-stak error parsing df with NFS
* Sun Oct 20 2013 andreas.stieger@gmx.de
- use re-released 2.2.5 tarball without backup files
* Thu Oct 17 2013 andreas.stieger@gmx.de
- update to 2.2.5:
  * Query_time histogram has been added to the pt-query-digest JSON
    output, not the actual chart but the values necessary to render
    the chart later, so the values for each bucket.
  * As of pt-table-checksum 2.2.5, skipped chunks cause a non-zero
    exit status. An exit status of zero or 32 is equivalent to a zero
    exit status with skipped chunks in previous versions of the tool.
  * New --no-drop-triggers option has been implemented for
    pt-online-schema-change in case users want to rename the tables
    manually, when the load is low.
  * New --new-table-name option has been added to
    pt-online-schema-change which can be used to specify the
    temporary table name.
- Bugs Fixed:
  * pt-archiver would delete the data even with the --dry-run option.
  * pt-query-digest didn’t distill LOAD DATA correctly.
  * pt-query-digest didn’t distill INSERT/REPLACE without INTO
    correctly.
  * pt-agent docs were referencing wrong web address.
  * pt-table-checksum --recursion-method=cluster option would crash
    if no nodes were found.
* Thu Jul 18 2013 andreas.stieger@gmx.de
- update to 2.2.4:
  * Implemented pt-query-digest anonymous JSON output
  * Implemented pt-online-schema-change timestamp output
- fixing the following bugs:
  * Zero values causes "Invalid --set-vars value: var=0"
  * pt-deadlock-logger error: Use of uninitialized value $ts in pattern match (m//)
  * pt-heartbeat docs don't account for --utc
  * pt-online-schema-change error copying rows: Undefined subroutine &pt_online_schema_change::get
  * pt-query-digest docs don't mention --type=rawlog
  * pt-query-digest doesn't group db and `db` together
  * pt-query-digest and pt-fingerprint don't strip some multi-line comments
  * pt-sift does not work if pt-stalk did not collect due to a full disk
  * pt-table-checksum: Deep recursion on subroutine "SchemaIterator::_iterate_dbh"
  * pt-table-checksum doesn't use non-unique index with highest cardinality
  * pt-table-checksum fails if explicit_defaults_for_timestamp is enabled in 5.6
  * pt-upgrade reports differences on NULL
  * pt-variable-advisor has the wrong default value for innodb_max_dirty_pages_pct in 5.5 and 5.6
  * pt-variable-advisor shows key_buffer_size in 5.6 as unconfigured (even though it is)
* Wed Jul  3 2013 andreas.stieger@gmx.de
- update to 2.2.3
  * Added new tool: pt-agent
  * Fixed bug: pt-online-schema-change causes "ERROR 1146 (42S02):
    Table 'db._t_new' doesn't exist"
* Mon Apr 29 2013 andreas.stieger@gmx.de
- update to 2.2.2
  * Added --show-all to pt-query-digest
  * Added --recursion-method=cluster to pt-table-checksum
- fixing the following bugs:
  * pt-archiver --bulk-insert may corrupt data
  * pt-heartbeat --utc --check always returns 0
  * pt-query-digest --processlist reports duplicate queries for
    replication thread
  * pt-query-digest 2.2 prints unwanted debug info on tcpdump
    parsing errors
  * pt-query-digest 2.2 prints too many string values
  * pt-stalk prints the wrong variable name in verbose mode when
  - -function is used
  * pt-stalk plugins can't access the real --prefix
  * pt-table-checksum pxc same_node function incorrectly uses
    wsrep_sst_receive_address
  * Some tools don't have --help or --version
  * Some tools use @@hostname without /*!50038*/
  * An explicitly set wsrep_node_incoming_address may make SHOW
    STATUS LIKE 'wsrep_incoming_addresses' return a portless address
* Mon Apr  8 2013 andreas.stieger@gmx.de
- update to 2.2.1
  This is the first release in the 2.2 series. Users are advised to
  re-read documentation for tools.
- new features:
  * Support for MySQL 5.6
  * Support for Percona XtraDB Cluster
- major updates:
  * Redesigned pt-query-digest
  * Redesigned pt-upgrade
  * Redesigned pt-fk-error-logger
  * Redesigned pt-deadlock-logger
- changed options:
  * Changed --set-vars in all tools
  * Renamed --retries to --tries in pt-online-schema-change
  * Added --check-read-only to pt-heartbeat
  * Added MySQL options to pt-mysql-summary
  * Added MySQL options to pt-stalk
- removed switches:
  * Removed --lock-wait-timeout from pt-online-schema-change (use --set-vars)
  * Removed --lock-wait-timeout from pt-table-checksum (use --set-vars)
- removed tools:
  * Removed pt-query-advisor
  * Removed pt-tcp-model
  * Removed pt-trend
  * Removed pt-log-player
- new defaults:
  * Enabled --version-check by default in all tools
- fixing the following bugs:
  * Fixed bug: Several tools don't have --database
  * Fixed bug: Quoter::serialize_list() doesn't handle multiple NULL values
  * Fixed bug: pt-config-diff needs to parse wsrep_provider_options
  * Fixed bug: pt-fk-error-logger --run-time works differently than pt-deadlock-logger --run-time
  * Fixed bug: pt-online-schema-change doesn't retry RENAME TABLE
  * Fixed bug: pt-online-schema-change blocks on metadata locks
  * Fixed bug: pt-stalk --no-stalk silently clobbers other options, acts magically
  * Fixed bug: pt-stalk truncates InnoDB status if there are too many transactions
  * Fixed bug: pt-table-checksum doesn't warn if no slaves are found
* Fri Feb 15 2013 andreas.stieger@gmx.de
- update to 2.1.9 [bnc#804102], fixing the following bugs:
  * pt-heartbeat 2.1.8 doesn't use precision/sub-second timestamps
  * pt-heartbeat 2.1.8 reports big time drift with UTC_TIMESTAMP
  * pt-online-schema-change fails with "Duplicate entry" on MariaDB
  * pt-online-schema-change makes bad DELETE trigger if PK is re-created with new columns
  * pt-pmp doesn't list the origin lib for each function
  * pt-query-digest shouldn't print "Error: none" for tcpdump
  * pt-query-digest fails to parse non-SQL errors
  * pt-table-checksum: Confusing error message with binlog_format ROW or MIXED on slave
  * pt-table-sync false-positive error "Cannot nibble table because MySQL chose no index
    instead of the PRIMARY index"
  * pt-stalk is too verbose, fills up log
* Fri Jan 11 2013 andreas.stieger@gmx.de
- update to 2.1.8
  * Beta support for MySQL 5.6
  * Beta support for Percona XtraDB Cluster
  * pt-online-schema-change: If ran on Percona XtraDB Cluster, requires PXC 5.5.28 or newer
  * pt-table-checksum: If ran on Percona XtraDB Cluster, requires PXC 5.5.28 or newer
  * pt-upgrade: Added --[no]disable-query-cache
- fixing the following bugs:
  * Bad pod2rst transformation
  * Bad online docs formatting for --[no]vars
  * pt-config-diff is case-sensitive
  * pt-config-diff doesn't handle end-of-line comments
  * pt-config-diff Use of uninitialized value in substitution (s///) at line 1996
  * pt-deadlock-logger doesn't handle usernames with dashes
  * pt-heartbeat handles timezones inconsistently
  * pt-kill --log-dsn timestamp is wrong
  * pt-mysql-summary doesn't handle renamed variables in Percona Server 5.5
  * pt-online-schema-change checks for foreign keys on MyISAM tables
  * pt-query-advisor hangs on big queries
  * pt-query-advisor RES.001 is incorrect
  * pt-query-advisor false positive on RES.001
  * pt-query-advisor issues wrong RES.001
  * pt-query-digest fails to parse timestamp with no query
  * pt-query-digest doesn't parse general log with "Connect user as user"
  * pt-query-digest with custom --group-by throws error
  * pt-query-digest prints negative byte offset
  * pt-query-digest help output mangled
  * pt-slave-restart CHANGE MASTER query causes error
  * pt-stalk purge_samples slows down checks
  * pt-stalk does not report NFS iostat
  * pt-table-checksum doesn't ignore tables for --replicate-check-only
  * pt-table-checksum v2 fails when --resume + --ignore-database is used
  * pt-table-checksum debug statement for "Chosen hash func" prints undef
  * pt-table-checksum Illegal division by zero at line 7950
  * pt-table-checksum uninitialized value in numeric lt (<) at line 8611
  * Tools let --set-vars clobber the required SQL mode
- also contains fixes from 2.1.7:
  * pt-table-checksum 2.1.6 crashes using PTDEBUG
  * pt-table-checksum 2.1.6 --check-binlog-format doesn't ignore PXC nodes
* Mon Nov 19 2012 andreas.stieger@gmx.de
- update to 2.1.6
  * pt-online-schema-change: Columns can now be renamed without data loss
  * pt-online-schema-change: New --default-engine option
  * pt-stalk: Plugin hooks available through the --plugin option to extend the tool's functionality
- fixing the following bugs
  * --version-check default should be explicitly "off"
  * LOAD DATA LOCAL INFILE broken in some platforms
  * Useless use of cat in Daemon.pm
  * Tools exit 0 on error parsing options, should exit non-zero
  * pt-table-checksum doesn't warn if binlog_format=row or mixed on slaves
  * pt-table-checksum breaks replication if a slave table is missing or different
  * pt-table-checksum doesn't honor --run-time while checking replication lag
  * pt-table-checksum error: Use of uninitialized value in int at line 2778
  * pt-table-checksum can crash with --columns if none match
  * pt-table-checksum dies if creating the --replicate table fails
  * pt-table-checksum doesn't test all hash functions
  * pt-table-checksum 2.1.4 doesn't detect diffs on Percona XtraDB Cluster nodes
  * pt-deadlock-logger can't parse db/tbl/index on partitioned tables
  * pt-online-schema-change DELETE trigger fails when altering primary key
  * pt-online-schema-change fails if sql_mode explicitly or implicitly uses ANSI_QUOTES
  * pt-online-schema-change fails with "I need a max_rows argument"
  * pt-online-schema-change --quiet doesn't disable --progress
  * pt-online-schema-change doesn't report how many warnings it suppressed
  * pt-upgrade fails if select column > 64 chars
  * pt-mysql-summary may report the wrong cnf file
  * pt-mysql-summary incorrectly categorizes databases
  * pt-show-grant doesn't support column-level grants
  * pt-query-digest review table privilege checks don't work
  * pt-query-digest docs for event attributes link to defunct Maatkit wiki
  * pt-duplicate-key-checker fails when it encounters a crashed table
  * pt-stalk deletes non-empty files
  * pt-stalk --no-stalk and --iterations 1 don't wait for the collect
  * pt-fifo-split is processing n-1 rows initially
  * pt-find documentation error with mtime and InnoDB
  * pt-trend output has no header
  * pt-visual-explain docs link to missing pdf
  * pt-fk-error-logger crashes if there's no foreign key error
  * pt-fk-error-logger --dest table example doesn't work
* Sun Nov 11 2012 andreas.stieger@gmx.de
- fix SLE 11 build by adding alternative perl macros
* Tue Oct 16 2012 andreas.stieger@gmx.de
- update to 2.1.5
  * pt-table-checksum 2.1.4 doesn't detect diffs on Percona XtraDB
    Cluster nodes
  * pt-table-checksum 2.1.4 miscategorizes Percona XtraDB Cluster-based
    slaves as cluster nodes
  * pt-table-sync 2.1.4 --version-check may not work with HTTPS/SSL
  * Missing version-check page
* Tue Oct  2 2012 andreas.stieger@gmx.de
- update to 2.1.4
  * pt-table-checksum: Percona XtraDB Cluster support
  * pt-table-checksum: Implemented the standard --run-time option
  * Implemented the version-check feature in several tools, enabled with the --version-check option
  * Document gdb dependency
  * Unquoted arguments to tr break the bash tools
- fixing the following Percona bugs:
  * pt-diskstats shows wrong device names
  * pt-duplicate-key-checker error parsing InnoDB table with no PK or unique keys
  * pt-online-schema-change dropping FK limitation isn't documented
  * pt-online-schema-changes fails if db+tbl name exceeds 64 characters
  * pt-query-digest --type tcpdump memory usage keeps increasing
  * pt-query-digest won't distill LOCK TABLES in lowercase
  * pt-stalk warns about bad "find" usage
  * pt-stalk df -h throws away needed details
  * pt-stalk --notify-by-email fails
  * pt-stalk does not get all InnoDB lock data
  * pt-summary should show information about Fusion-io cards
  * pt-table-checksum doesn't work if slaves use RBR
  * pt-table-checksum --check-slave-lag docs aren't clear
  * pt-table-checksum --defaults-file isn't used for slaves
  * pt-table-sync and text columns with just whitespace
  * pt-table-sync base_count fails on n = 1000, base = 10
  * pt-table-sync division by zero error with varchar primary key
  * pt-table-sync priv checks need to be removed
  * pt-upgrade error "I need a right_sth argument"
  * sh warnings in pt-summary and pt-mysql-summary
  * ChangeHandler doesn't quote varchar columns with hex-looking values
  * CentOS 5 yum dependency resolution for perl module is wrong
  * Percona Toolkit RPM should contain a dependency on perl-Time-HiRes
* Wed Sep  5 2012 andreas.stieger@gmx.de
- initial package for Percona Toolkit 2.1.3,
  based on upstream spec file some OBS occurrences
- based on and replacing Maatkit, obsoleting their last release 7410
